@@ -25,7 +25,7 @@ sub load_config {
 1;
 ...
 
-    $self->write_file('lib/<<PATH>>/Web.pm', <<'...');
+    $self->write_file('lib/<<PATH>>/Web.pm', <<'...', { xslate => $self->create_view() });
 package <% $module %>::Web;
 use strict;
 use warnings;
@@ -39,25 +39,7 @@ sub dispatch {
     $c->render('index.tt');
 }
 
-# setup view class
-use Text::Xslate;
-{
-    my $view_conf = __PACKAGE__->config->{'Text::Xslate'} || +{ };
-    unless (exists $view_conf->{path}) {
-        $view_conf->{path} = [ File::Spec->catdir(__PACKAGE__->base_dir(), 'tmpl') ];
-    }
-    my $view = Text::Xslate->new(+{
-        'syntax'   => 'TTerse',
-        'module'   => [ 'Text::Xslate::Bridge::TT2Like' ],
-        'function' => {
-            c        => sub { Amon2->context() },
-            uri_with => sub { Amon2->context()->req->uri_with(@_) },
-            uri_for  => sub { Amon2->context()->uri_for(@_) },
-        },
-        %$view_conf
-    });
-    sub create_view { $view }
-}
+<% $xslate %>
 
 # for your security
 __PACKAGE__->add_trigger(
@@ -142,7 +124,7 @@ done_testing;
 ...
 
     $self->write_file('t/Util.pm', <<'...');
-package t::Util;
+package <% '' %>t::Util;
 BEGIN {
     unless ($ENV{PLACK_ENV}) {
         $ENV{PLACK_ENV} = 'test';
@@ -217,6 +199,55 @@ all_pod_files_ok();
 ...
 }
 
+sub create_view {
+    my $self = shift;
+
+    $self->render_string(<<'...', @_);
+# setup view class
+use Text::Xslate;
+{
+    my $view_conf = __PACKAGE__->config->{'Text::Xslate'} || +{};
+    unless (exists $view_conf->{path}) {
+        $view_conf->{path} = [ File::Spec->catdir(__PACKAGE__->base_dir(), '<% $tmpl_path ? $tmpl_path : 'tmpl' %>') ];
+    }
+    my $view = Text::Xslate->new(+{
+        'syntax'   => 'TTerse',
+        'module'   => [ 'Text::Xslate::Bridge::TT2Like' ],
+        'function' => {
+            c => sub { Amon2->context() },
+            uri_with => sub { Amon2->context()->req->uri_with(@_) },
+            uri_for  => sub { Amon2->context()->uri_for(@_) },
+            static_file => do {
+                my %static_file_cache;
+                sub {
+                    my $fname = shift;
+                    my $c = Amon2->context;
+                    if (not exists $static_file_cache{$fname}) {
+                        my $fullpath = File::Spec->catfile($c->base_dir(), $fname);
+                        $static_file_cache{$fname} = (stat $fullpath)[9];
+                    }
+                    return $c->uri_for($fname, { 't' => $static_file_cache{$fname} || 0 });
+                }
+            },
+        },
+        %$view_conf
+    });
+    sub create_view { $view }
+}
+...
+}
+
+sub psgi_header {
+    <<'...';
+use strict;
+use File::Spec;
+use File::Basename;
+use lib File::Spec->catdir(dirname(__FILE__), 'extlib', 'lib', 'perl5');
+use lib File::Spec->catdir(dirname(__FILE__), 'lib');
+use Plack::Builder;
+...
+}
+
 1;
 __END__
 
